Chatham County Court Case Search System - Home

## Cookies must be allowed.

Your browser is currently set to block cookies. Your browser must allow cookies before you can use this application.

Cookies are small text files stored on your computer that tell this application when you're signed in. To learn how to allow cookies, see online help in your web browser.

## You are using a web browser which this application no longer supports.

We support the current and previous major releases of Google Chrome, Firefox, Internet Explorer, and Safari on a rolling basis. Each time a new version is released, we begin supporting that version and stop supporting the third most recent version.

## Supported Browsers

Chrome for Business
Firefox
Internet Explorer
Apple Safari

Internet Explorer 9 Users Internet Explorer 11 launched on October 17, 2013, and as a result, we've discontinued support for Internet Explorer 9.

Organizations that depend on old versions of Internet Explorer may want to consider a dual browser strategy.

# Notifications

To view public documents a user must register and request access. Public documents are availabe for puchase for Superior, State, Magistrate, Probate and Recorders Courts. In order to view cases properly you must use Internet Explorer. If you have issues with viewing all the documents, make sure you are viewing the document in Windows Photo Viewer.

Chatham Courts Homepage

Portal Troubleshooting

Portal Frequently Asked Questions

Portal User Guide

******Online Citation/Portal payments are available. Please allow up to 48 hours for your payment to be reflected on this Portal. If you do not see your payment after 48 hours please contact the Court you made the payment to for confirmation of your payment. If you receive an error in processing your payment DO NOT process the payment again. Please contact the Court immediately. (Recorders Court (912) 652-7425)******

If you are experiencing any problems with your LOG IN, please email cjispm@chathamcounty.org

Recorders Court of Chatham County Website

As of March 2019, users are able to see date of births via the public access terminals located inside the Clerks offices in the Chatham County Courthouse only.

Smart Search

Search for court records.

Search Hearings

Search for court hearings for a specified date range.

Make Payments

Make a payment or select payment alternatives for criminal and traffic cases.

Machine: TOPORTAL1

## Are you still here?

Your session will expire in 60 seconds due to inactivity.